==> bilibili-api-python-14.0.0rc0.tar.gz: bilibili-api-python-14.0.0rc0/setup.py <==
import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

with open("requirements.txt", "r", encoding="utf8") as f:
    requires = f.read()

setuptools.setup(
    name="bilibili-api-python",
    version="14.0.0.rc",
    license="GPLv3+",
    author="Nemo2011,Passkou",
    description="哔哩哔哩的各种 API 调用便捷整合（视频、动态、直播等），另外附加一些常用的功能。",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=[
        "bilibili_api",
        "bilibili_api.utils",
        "bilibili_api.exceptions",
        "bilibili_api.errors",
        "bilibili_api.tools",
        "bilibili_api.tools.opendocs",
        "bilibili_api.tools.ivitools",
        "bilibili_api._pyinstaller",
    ],
    keywords=["bilibili", "api", "spider"],
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Natural Language :: Chinese (Simplified)",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    package_data={
        "": ["data/**/*.*", "py.typed", "requirements.txt", "data/*.*", "html/*.*", "css/*.*"]
    },
    install_requires=requires.splitlines(),
    url="https://github.com/nemo2011/bilibili-api",
    python_requires=">=3.8",
    entry_points={
        "pyinstaller40": [
            "hook-dirs = bilibili_api._pyinstaller.entry_points:get_hook_dirs"
        ],
        "console_scripts": [
            "bilibili-api-docs = bilibili_api.tools.opendocs.__main__:main",
            "ivitools = bilibili_api.tools.ivitools.__main__:main"
        ],
    },
)

==> bilibili-api-python-14.2.0.tar.gz: bilibili-api-python-14.2.0/setup.py <==
import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

with open("requirements.txt", "r", encoding="utf8") as f:
    requires = f.read()

setuptools.setup(
    name="bilibili-api-python",
    version="14.2.0",
    license="GPLv3+",
    author="Nemo2011",
    author_email="yimoxia@outlook.com",
    maintainer="MoyuScript, Nemo2011",
    description="哔哩哔哩的各种 API 调用便捷整合（视频、动态、直播等），另外附加一些常用的功能。",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=[
        "bilibili_api",
        "bilibili_api.utils",
        "bilibili_api.exceptions",
        "bilibili_api.errors",
        "bilibili_api.tools",
        "bilibili_api.tools.opendocs",
        "bilibili_api.tools.ivitools",
        "bilibili_api._pyinstaller",
    ],
    keywords=["bilibili", "api", "spider"],
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Natural Language :: Chinese (Simplified)",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    package_data={
        "": ["data/**/*.*", "py.typed", "requirements.txt", "data/*.*", "data/article/*.*", "data/geetest/*.*", "data/corerespond/*.*"]
    },
    install_requires=requires.splitlines(),
    url="https://github.com/nemo2011/bilibili-api",
    python_requires=">=3.8",
    entry_points={
        "pyinstaller40": [
            "hook-dirs = bilibili_api._pyinstaller.entry_points:get_hook_dirs"
        ],
        "console_scripts": [
            "bilibili-api-docs = bilibili_api.tools.opendocs.__main__:main",
            "ivitools = bilibili_api.tools.ivitools.__main__:main"
        ],
    },
)
